package Task::Setup;

our $VERSION = '0.03'; # VERSION

1;
# ABSTRACT: Install all Setup modules


__END__
=pod

=head1 NAME

Task::Setup - Install all Setup modules

=head1 VERSION

version 0.03

=head1 DESCRIPTION

This task will install all Setup modules.

=head1 TASK CONTENTS

=head2 Included modules

=head3 L<Setup>

=head3 L<Setup::File>

=head3 L<Setup::File::Symlink>

=head3 L<Setup::Text::Snippet>

=head3 L<Setup::Unix::User>

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

